Supvisors status

Name | State | Description | Load | CPU | MEM | Actions | Log
--- | --- | --- | --- | --- | --- | --- | ---
Name | State | Description | Load | CPU | MEM | Actions | Log
Name | State | Description | 5% | -- | -- | Start | Stop | Restart | Clear | Stdout | Stderr

#### Detailed Statistics -- *

CPU | MEM
--- | ---
% | Mean % | Slope % | SD % | % | Mean % | Slope % | SD %
-- | -- | -- | -- | -- | -- | -- | --